summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/libpng/pngmem.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/libpng/pngmem.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c b/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
index c94a33d..66eec0b 100644
--- a/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
+++ b/tqtinterface/qt4/src/3rdparty/libpng/pngmem.c
@@ -8,10 +8,10 @@
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
* This file provides a location for all memory allocation. Users who
- * need special memory handling are expected to supply tqreplacement
+ * need special memory handling are expected to supply replacement
* functions for png_malloc() and png_free(), and to use
* png_create_read_struct_2() and png_create_write_struct_2() to
- * identify the tqreplacement functions.
+ * identify the replacement functions.
*/
#define PNG_INTERNAL
@@ -21,7 +21,7 @@
#if defined(__TURBOC__) && !defined(_Windows) && !defined(__FLAT__)
/* if you change this, be sure to change the one in png.h also */
/* Allocate memory for a png_struct. The malloc and memset can be tqreplaced
by a single call to calloc() if this is thought to improve performance. */
png_voidp /* PRIVATE */
png_create_struct(int type)
@@ -305,7 +305,7 @@ png_free_default(png_structp png_ptr, png_voidp ptr)
#else /* Not the Borland DOS special memory handler */
/* Allocate memory for a png_struct or a png_info. The malloc and
- memset can be tqreplaced by a single call to calloc() if this is thought
+ memset can be replaced by a single call to calloc() if this is thought
to improve performance noticably. */
png_voidp /* PRIVATE */
png_create_struct(int type)
@@ -315,7 +315,7 @@ png_create_struct(int type)
}
/* Allocate memory for a png_struct or a png_info. The malloc and
- memset can be tqreplaced by a single call to calloc() if this is thought
+ memset can be replaced by a single call to calloc() if this is thought
to improve performance noticably. */
png_voidp /* PRIVATE */
png_create_struct_2(int type, png_malloc_ptr malloc_fn, png_voidp mem_ptr)
@@ -21,7 +21,7 @@
#if defined(__TURBOC__) && !defined(_Windows) && !defined(__FLAT__)
/* if you change this, be sure to change the one in png.h also */
-/* Allocate memory for a png_struct. The malloc and memset can be tqreplaced
+/* Allocate memory for a png_struct. The malloc and memset can be replaced
by a single call to calloc() if this is thought to improve performance. */
png_voidp /* PRIVATE */